summaryrefslogtreecommitdiffstats
path: root/test/dt_arith.c
diff options
context:
space:
mode:
authorRaymond Lu <songyulu@hdfgroup.org>2005-09-14 19:10:37 (GMT)
committerRaymond Lu <songyulu@hdfgroup.org>2005-09-14 19:10:37 (GMT)
commitf7c075c736d3a4615cc78308111c235a91dbdc5d (patch)
treec4271fc33ae3cdf069d6fb2295207bf185dde671 /test/dt_arith.c
parent33beeb7f55193bc76a7544f9fe3634718f36352d (diff)
downloadhdf5-f7c075c736d3a4615cc78308111c235a91dbdc5d.zip
hdf5-f7c075c736d3a4615cc78308111c235a91dbdc5d.tar.gz
hdf5-f7c075c736d3a4615cc78308111c235a91dbdc5d.tar.bz2
[svn-r11414] Purpose: Rename a API function
Description: The API function H5Tis_hard() which was recently checked in has been renamed to H5Tcompiler_conv() to be more descriptive. No other changes. Platforms tested: fuss - simple change. Misc. update: config/lt_vers.am to update libtool version.
Diffstat (limited to 'test/dt_arith.c')
-rw-r--r--test/dt_arith.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/test/dt_arith.c b/test/dt_arith.c
index 7b025a5..c9af208 100644
--- a/test/dt_arith.c
+++ b/test/dt_arith.c
@@ -581,7 +581,7 @@ generates_sigfpe(void)
/*-------------------------------------------------------------------------
* Function: test_hard_query
*
* Purpose: Tests H5Tis_hard() for querying whether a conversion is
* a hard one.
*
* Return: Success: 0
@@ -600,10 +600,10 @@ test_hard_query(void)
{
htri_t ret;
- TESTING("query functions of hard conversion");
+ TESTING("query functions of compiler conversion");
/* Verify the conversion from int to float is a hard conversion. */
- if((ret = H5Tis_hard(H5T_NATIVE_INT, H5T_NATIVE_FLOAT))!=TRUE) {
+ if((ret = H5Tcompiler_conv(H5T_NATIVE_INT, H5T_NATIVE_FLOAT))!=TRUE) {
H5_FAILED();
printf("Can't query conversion function\n");
goto error;
@@ -612,7 +612,7 @@ test_hard_query(void)
/* Unregister the hard conversion from int to float. Verify the conversion
* is a soft conversion. */
H5Tunregister(H5T_PERS_HARD, NULL, H5T_NATIVE_INT, H5T_NATIVE_FLOAT, NULL);
- if((ret = H5Tis_hard(H5T_NATIVE_INT, H5T_NATIVE_FLOAT))!=FALSE) {
+ if((ret = H5Tcompiler_conv(H5T_NATIVE_INT, H5T_NATIVE_FLOAT))!=FALSE) {
H5_FAILED();
printf("Can't query conversion function\n");
goto error;
@@ -621,7 +621,7 @@ test_hard_query(void)
/* Register the hard conversion from int to float. Verify the conversion
* is a hard conversion. */
H5Tregister(H5T_PERS_HARD, "int_flt", H5T_NATIVE_INT, H5T_NATIVE_FLOAT, H5T_conv_int_float);
- if((ret = H5Tis_hard(H5T_NATIVE_INT, H5T_NATIVE_FLOAT))!=TRUE) {
+ if((ret = H5Tcompiler_conv(H5T_NATIVE_INT, H5T_NATIVE_FLOAT))!=TRUE) {
H5_FAILED();
printf("Can't query conversion function\n");
goto error;
@@ -5052,7 +5052,7 @@ main(void)
/* Do the tests */
/* Test H5Tis_hard() for querying hard conversion. */
nerrors += test_hard_query();
/* Test user-define, query functions and software conversion
@@ -581,7 +581,7 @@ generates_sigfpe(void)
* Function: test_hard_query
*
- * Purpose: Tests H5Tis_hard() for querying whether a conversion is
+ * Purpose: Tests H5Tcompiler_conv() for querying whether a conversion is
* a hard one.
*
@@ -5052,7 +5052,7 @@ main(void)
/* Do the tests */
- /* Test H5Tis_hard() for querying hard conversion. */
+ /* Test H5Tcompiler_conv() for querying hard conversion. */
nerrors += test_hard_query();
/* Test user-define, query functions and software conversion